Settings that django_comments understands — Django Comments 1.5 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Django Comments 1.5 documentation »

# Settings that `django_comments` understands

## COMMENTS_HIDE_REMOVED

If `True` (default), removed comments will be excluded from comment lists/counts (as taken from template tags). Otherwise, the template author is responsible for some sort of a “this comment has been removed by the site staff” message.

## COMMENT_MAX_LENGTH

The maximum length of the comment field, in characters. Comments longer than this will be rejected. Defaults to 3000.

## COMMENTS_APP

An app which provides customization of the comments framework. Use the same dotted-string notation as in `INSTALLED_APPS`. Your custom `COMMENTS_APP` must also be listed in `INSTALLED_APPS`.

### Navigation

- index
- modules |
- next |
- previous |
- Django Comments 1.5 documentation »